pub struct SField<T, const CODE: i32> { /* private fields */ }Expand description
A type-safe wrapper for XRPL serialized field codes.
This struct encodes both the field code and the expected type as const generics,
allowing the compiler to automatically infer the correct type when calling get_field.
The type parameter T represents the expected Rust type for this field, which can be
used with the field-decoder marker traits FromCurrentTx and FromLedger.
Example
use xrpl_common_stdlib::objects::ledger_object;
use xrpl_common_stdlib::current_tx;
use xrpl_common_stdlib::types::amount::Amount;
use xrpl_common_stdlib::sfield;
use xrpl_common_stdlib::types::account_id::AccountID;
// Type is automatically inferred from the SField constant, for both ledger_objects and current_transaction:
let flags:u32 = ledger_object::get_field(0, sfield::Flags).unwrap(); // u32
let balance:Amount = ledger_object::get_field(0, sfield::Balance).unwrap(); // u64
// current transaction:
let account:AccountID = current_tx::get_field(sfield::Account).unwrap(); // AccountID
let sequence:u32 = current_tx::get_field(sfield::Sequence).unwrap(); // u32Implementations